<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
<link rel="stylesheet" href="/css/style.css" type="text/css" />

<title> Day Day Up </title>
</head>
<body>

<p> <a href="/">Index</a> | <a href="/notes/">Notes</a> </p>

<hr />

[% content %]

<hr />

Powered by DayDayUp [% c.VERSION %]

</body>
</html>